@@ -16,10 +16,11 @@ CLOUD_DEFAULTS = dict(
     hp=dict(
         auth_url='https://region-b.geo-1.identity.hpcloudsvc.com:35357/v2.0',
         region_name='region-b.geo-1',
-        dns_service_type='hp:dns',
+        dns_service_type='hpext:dns',
     ),
     rackspace=dict(
         auth_url='https://identity.api.rackspacecloud.com/v2.0/',
         database_service_type='rax:database',
+        image_api_version='2',
     )
 )
